% example Quokka3 settingsfile
% PERC unit-cell from A. Fell et al., "Input parameters for the simulation of silicon solar cells in 2014", JPV 2015
%
% (c) 2021 Andreas Fell
%
% uses the simplified 'front and rear contact unit cell' syntax
% uses the 'busbar-enhanced' unit cell type
% the front finger pitch is different to the publication for an optimum efficiency
%
% calculates light trapping (i.e. Z) from internal optical properties of the skins,
% with a lower reflectivity at the contacted skin


Syntax = 'front and rear contact unit cell';

Solver.SolutionType = 'light JV-curve';
Solver.JVCurve.VtermStepSize = 'standard';
% Solver.QECurve.Type = 'biased';
% Solver.QECurve.Side = 'front';
% Solver.QECurve.JgenMonochromatic = 0.1;

Solver.Electrical.MetalModelType = 'finite-differences';
Solver.Electrical.SkinJ0nieff.Type = 'user-const';
Solver.Electrical.SkinJ0nieff.Const = 8.27e9;

ExternalCircuit.Enable = 0; % do not add Rseries as metal resistance is solved by finite-differences

UnitCellType = 'busbar-enhanced';

CellThickness = 180;
FrontContactShape = 'line';
FrontMetalShape = 'H-pattern';
FrontContactPitch = 1360; % (close to) optimum pitch of front fingers, different to publication
FrontFingerWidth = 60; % [m] full width of front fingers
FrontFingerShadingFraction = 0.7;
FrontContactWidth = 60; %[m] full width of contact opening underneath fingers
FrontContact.OhmicResistivity = 2e-3; % [Ohmcm2]

RearContactShape = 'line';
RearMetalShape = 'full';
RearContact.OhmicResistivity = 5e-3; % [Ohmcm2]
% for localized rear contacts only
RearContactPitch = 850;
RearContactWidth = 120;

% busbar-enhanced settings
BusbarPitch = 52 mm; % 
FrontBusbarWidth = 1300; % [m] width of busbars
FrontBusbarContactEnable = 0;% 1, 0 whether busbar has contact, also determines whether selective skin would be present under busbar
RearBusbarWidth = 1300; % [m] width of busbars
RearBusbarContactEnable = 0;% 1, 0 whether busbar has contact, also determines whether selective skin would be present under busbar
% finite-difference modeling of metal only; busbar and rear-metal resistance is neglected
FrontMetalRsheet = 0.00375; % [Ohm] Rsheet of front fingers
RearMetalRsheet = 0.00375; % [Ohm] Rsheet of rear fingers

FrontMetalPolarity = 'n-type';
RearMetalPolarity = 'p-type';

Thermal.T = 298.15;

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'p-type';
Bulk.BackgroundDoping.Resistivity = 2;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'tau-Et';
Bulk.Electrical.Recombination.SRH(1).taun = 371;
Bulk.Electrical.Recombination.SRH(1).taup = 3710;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = 0;
Bulk.Electrical.Recombination.SRH(2).Type = 'inactive-doping'; % enables inactive doping recombination within the front diffusion
Bulk.Electrical.Recombination.SRH(2).sigmap = 7.5e-18; % from Min 2014
Bulk.Electrical.Recombination.SRH(2).sigman = 7.5e-18; % same value, no effect for phosphorus doping
Bulk.Electrical.Recombination.SRH(2).Et_Ei = 0; % irrelevant for high doping

Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.RearIllumination.Enable = 0;
Optical.TextZ.FrontText.Type = 'Text';
Optical.TextZ.FrontText.Text.Type = 'file';
Optical.TextZ.FrontText.Text.File = 'PERC_commercial_Tfront_bb_scaled.csv'; % scaled by busbar shading; must be changed to unscaled Text for busbar-enhanced unit-cell
Optical.TextZ.FrontText.FacetAngle = 54;
Optical.TextZ.FrontZ.Type = 'parameterization'; % the below parameterization is a best-fit to the published optical properties
Optical.TextZ.FrontZ.Z0 = 48.25;
Optical.TextZ.FrontZ.Zinf = 1.6;
Optical.TextZ.FrontZ.Zp = 2.229;
Optical.ScaleGeneration = 1;

% full area front skin properties (e.g. front emitter)
FullFrontSkin.ElectricalModelType = 'detailed';
FullFrontSkin.Layer(1).Name = 'front diffusion';
FullFrontSkin.Layer(1).Type = 'near-surface';
FullFrontSkin.Layer(1).DopingProfile.DopingType = 'n-type';
FullFrontSkin.Layer(1).DopingProfile.Type = 'file';
FullFrontSkin.Layer(1).DopingProfile.File = 'PERC_DopingProfile_Total.csv';
FullFrontSkin.Layer(1).ActiveProfile.DopingType = 'n-type';
FullFrontSkin.Layer(1).ActiveProfile.Type = 'file';
FullFrontSkin.Layer(1).ActiveProfile.File = 'PERC_DopingProfile_Active.csv';
FullFrontSkin.Layer(1).SurfaceRecombination.Type = 'Si-SiNx-Min2014';
FullFrontSkin.Detailed.Multiscale.ModelType = 'single point'; % sinlge point coupling sufficient for diffused emitter
FullFrontSkin.Detailed.Multiscale.TextureMultiplier = 1.2;

LocalFrontContactSkin.Enable = 1; % enable a local skin beneath the front fingers here to set an empirical J0_cont independently of the doping profile
LocalFrontContactSkin.ElectricalModelType = 'lumped';
LocalFrontContactSkin.Lumped.Electrical.RsheetEnable = 1;
LocalFrontContactSkin.Lumped.Electrical.Rsheet = 82;
LocalFrontContactSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
LocalFrontContactSkin.Lumped.Electrical.ContactedRecombination.J0 = 1200e-15;

% non-contacted rear skin properties (e.g. passivated rear); for localized rear contacts only
FullRearSkin.ElectricalModelType = 'lumped';
FullRearSkin.Lumped.Electrical.RsheetEnable = 0;
FullRearSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullRearSkin.Lumped.Electrical.NonContactedRecombination.J0 = 13.1e-15;

% contacted rear skin properties (e.g. Al-BSF)
LocalRearContactSkin.Enable = 1;
LocalRearContactSkin.ElectricalModelType = 'lumped';
LocalRearContactSkin.Lumped.Electrical.RsheetEnable = 1;
LocalRearContactSkin.Lumped.Electrical.Rsheet = 61;
LocalRearContactSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
LocalRearContactSkin.Lumped.Electrical.ContactedRecombination.J0 = 795e-15;

